@@ -11,7 +11,7 @@ import argparse
 def get_args_parser():
     parser = argparse.ArgumentParser(description="bloggart command line interface.")
     parser.add_argument("-c", "--config", default='config.ini', help="配置文件路径")
-    parser.add_argument("-p", "--port", default='config.ini', help="配置文件路径")
+    parser.add_argument("-p", "--port", default=80, type=int, help="配置文件路径")
     return parser.parse_args()
 
 class MainHandler(tornado.web.RequestHandler):
@@ -25,7 +25,7 @@ def Run():
     handler = []
     handler.extend(database.Handle(config.Get_database()))
     handler.extend(fileserver.Handle(config.Get_fileserver()))
-    service.Serving(args.port, handler)
+    service.Serving(int(args.port), handler)
     
     print(config.CONFIG)
     exit()
